Explicitly releases the native resources owned by an open Parquet handle. Closing an already closed handle has no effect.
Examples
path <- tempfile(fileext = ".parquet")
write_parquet(mtcars, path)
pf <- open_parquet(path)
close_parquet(pf)
Explicitly releases the native resources owned by an open Parquet handle. Closing an already closed handle has no effect.
path <- tempfile(fileext = ".parquet")
write_parquet(mtcars, path)
pf <- open_parquet(path)
close_parquet(pf)